@@ -1,3 +1,4 @@
+/*
 use futures::join;
 use radiobrowser::RadioBrowserAPI;
 use radiobrowser::StationOrder;
@@ -27,3 +28,18 @@ async fn main() -> Result<(), Box<dyn Error>> {
     println!("Stations found: {}", stations?.len());
     Ok(())
 }
+*/
+
+use radiobrowser::blocking::RadioBrowserAPI;
+use std::error::Error;
+
+fn main() -> Result<(), Box<dyn Error>> {
+    let api = RadioBrowserAPI::new()?;
+    let servers = RadioBrowserAPI::get_servers()?;
+    println!("Servers: {:?}", servers);
+    let countries = api.get_countries().send()?;
+    println!("Countries: {:?}", countries);
+    let stations = api.get_stations().name("jazz").send()?;
+    println!("Stations: {:?}", stations);
+    Ok(())
+}
\ No newline at end of file
